@@ -239,13 +239,16 @@ create_future_rt <- function(future = c("latest", "project", "estimate"),
 #' Takes the output from [rt_opts()] and converts it into a list understood by
 #' stan.
 #' @param rt A list of options as generated by [rt_opts()] defining Rt
-#' estimation. Defaults to [rt_opts()]. Set to `NULL` to switch to using back
-#' calculation rather than generating infections using Rt.
+#' estimation. Defaults to [rt_opts()]. To generate new infections using
+#' the non-mechanistic model instead of the renewal equation model, use
+#' `rt = NULL`. The non-mechanistic model internally uses the setting
+#' `rt = rt_opts(use_rt = FALSE, future = "project", gp_on = "R0")`.
 #'
 #' @param breakpoints An integer vector (binary) indicating the location of
 #' breakpoints.
 #'
 #' @param horizon Numeric, forecast horizon.
+#' @importFrom cli cli_abort
 #'
 #' @seealso rt_settings
 #' @return A list of settings defining the time-varying reproduction number
@@ -261,15 +264,20 @@ create_future_rt <- function(future = c("latest", "project", "estimate"),
 #'
 #' # using breakpoints
 #' create_rt_data(rt_opts(use_breakpoints = TRUE), breakpoints = rep(1, 10))
+#'
+#' # using random walk
+#' create_rt_data(rt_opts(rw = 7), breakpoints = rep(1, 10))
 #' }
 create_rt_data <- function(rt = rt_opts(), breakpoints = NULL,
                            delay = 0, horizon = 0) {
+
   # Define if GP is on or off
   if (is.null(rt)) {
     rt <- rt_opts(
       use_rt = FALSE,
       future = "project",
-      gp_on = "R0"
+      gp_on = "R0",
+      rw = 0
     )
   }
   # define future Rt arguments
@@ -279,24 +287,38 @@ create_rt_data <- function(rt = rt_opts(), breakpoints = NULL,
   )
   # apply random walk
   if (rt$rw != 0) {
-    breakpoints <- as.integer(seq_along(breakpoints) %% rt$rw == 0)
+    if (is.null(breakpoints)) {
+      cli_abort(
+        c(
+          "!" = "breakpoints must be supplied when using random walk."
+        )
+      )
+    }
+
+    breakpoints <- seq_along(breakpoints)
+    breakpoints <- floor(breakpoints / rt$rw)
     if (!(rt$future == "project")) {
       max_bps <- length(breakpoints) - horizon + future_rt$from
       if (max_bps < length(breakpoints)) {
-        breakpoints[(max_bps + 1):length(breakpoints)] <- 0
+        breakpoints[(max_bps + 1):length(breakpoints)] <- breakpoints[max_bps]
       }
     }
+  }else {
+    breakpoints <- cumsum(breakpoints)
   }
-  # check breakpoints
-  if (is.null(breakpoints) || sum(breakpoints) == 0) {
+
+  if (sum(breakpoints) == 0) {
     rt$use_breakpoints <- FALSE
   }
+  # add a shift for 0 effect in breakpoints
+  breakpoints <- breakpoints + 1
+
   # map settings to underlying gp stan requirements
   rt_data <- list(
     r_mean = rt$prior$mean,
     r_sd = rt$prior$sd,
     estimate_r = as.numeric(rt$use_rt),
-    bp_n = ifelse(rt$use_breakpoints, sum(breakpoints, na.rm = TRUE), 0),
+    bp_n = ifelse(rt$use_breakpoints, max(breakpoints) - 1, 0),
     breakpoints = breakpoints,
     future_fixed =  as.numeric(future_rt$fixed),
     fixed_from = future_rt$from,
@@ -331,6 +353,7 @@ create_backcalc_data <- function(backcalc = backcalc_opts()) {
  )
  return(data)
 }
+
 #' Create Gaussian Process Data
 #'
 #' @description `r lifecycle::badge("stable")`
@@ -372,32 +395,50 @@ create_gp_data <- function(gp = gp_opts(), data) {
   } else {
     fixed <- FALSE
   }
-  # reset ls_max if larger than observed time
-  time <- data$t - data$seeding_time - data$horizon
-  if (gp$ls_max > time) {
-    gp$ls_max <- time
+
+  time <- data$t - data$seeding_time
+  if (data$future_fixed > 0) {
+    time <- time + data$fixed_from - data$horizon
+  }
+  if (data$stationary == 1) {
+    time <- time - 1
   }
 
+  obs_time <- data$t - data$seeding_time
+  if (gp$ls_max > obs_time) {
+    gp$ls_max <- obs_time
+  }
+
+  times <- seq_len(time)
+
+  rescaled_times <- (times - mean(times)) / sd(times)
+  gp$ls_mean <- gp$ls_mean / sd(times)
+  gp$ls_sd <- gp$ls_sd / sd(times)
+  gp$ls_min <- gp$ls_min / sd(times)
+  gp$ls_max <- gp$ls_max /  sd(times)
+
   # basis functions
-  M <- data$t - data$seeding_time
-  M <- ifelse(data$future_fixed == 1, M - (data$horizon - data$fixed_from), M)
-  M <- ceiling(M * gp$basis_prop)
+  M <- ceiling(time * gp$basis_prop)
 
   # map settings to underlying gp stan requirements
   gp_data <- list(
     fixed = as.numeric(fixed),
     M = M,
-    L = gp$boundary_scale,
+    L = gp$boundary_scale * max(rescaled_times),
     ls_meanlog = convert_to_logmean(gp$ls_mean, gp$ls_sd),
     ls_sdlog = convert_to_logsd(gp$ls_mean, gp$ls_sd),
     ls_min = gp$ls_min,
-    ls_max = data$t - data$seeding_time - data$horizon,
+    ls_max = gp$ls_max,
+    alpha_mean = gp$alpha_mean,
     alpha_sd = gp$alpha_sd,
     gp_type = data.table::fcase(
-    gp$kernel == "se", 0,
-    gp$kernel == "matern", 1,
-    default = 0
-    )
+      gp$kernel == "se", 0,
+      gp$kernel == "periodic", 1,
+      gp$kernel == "matern" || gp$kernel == "ou", 2,
+      default = 2
+    ),
+    nu = gp$matern_order,
+    w0 = gp$w0
   )
 
   gp_data <- c(data, gp_data)
@@ -590,42 +631,44 @@ create_initial_conditions <- function(data) {
     out <- create_delay_inits(data)
 
     if (data$fixed == 0) {
-      out$eta <- array(rnorm(data$M, mean = 0, sd = 0.1))
-      out$rho <- array(rlnorm(1,
+      out$eta <- array(rnorm(
+        ifelse(data$gp_type == 1, data$M * 2, data$M), mean = 0, sd = 0.1))
+      out$rescaled_rho <- array(rlnorm(1,
         meanlog = data$ls_meanlog,
-        sdlog = ifelse(data$ls_sdlog > 0, data$ls_sdlog * 0.1, 0.01)
+        sdlog = ifelse(data$ls_sdlog > 0, data$ls_sdlog, 0.01)
+      ))
+      out$rescaled_rho <- array(data.table::fcase(
+        out$rescaled_rho > data$ls_max, data$ls_max - 0.001,
+        out$rescaled_rho < data$ls_min, data$ls_min + 0.001,
+        default = out$rescaled_rho
       ))
 
-      out$rho <- array(data.table::fcase(
-        out$rho > data$ls_max, data$ls_max - 0.001,
-        out$rho < data$ls_min, data$ls_min + 0.001,
-        default = out$rho
-        ))
-
       out$alpha <- array(
-        truncnorm::rtruncnorm(1, a = 0, mean = 0, sd = data$alpha_sd)
+        truncnorm::rtruncnorm(
+          1, a = 0, mean = data$alpha_mean, sd = data$alpha_sd
+        )
       )
     } else {
       out$eta <- array(numeric(0))
-      out$rho <- array(numeric(0))
+      out$rescaled_rho <- array(numeric(0))
       out$alpha <- array(numeric(0))
     }
     if (data$model_type == 1) {
       out$rep_phi <- array(
         truncnorm::rtruncnorm(
           1,
-          a = 0, mean = data$phi_mean, sd = data$phi_sd / 10
+          a = 0, mean = data$phi_mean, sd = data$phi_sd
         )
       )
     }
     if (data$estimate_r == 1) {
-      out$initial_infections <- array(rnorm(1, data$prior_infections, 0.02))
+      out$initial_infections <- array(rnorm(1, data$prior_infections, 0.2))
       if (data$seeding_time > 1) {
-        out$initial_growth <- array(rnorm(1, data$prior_growth, 0.01))
+        out$initial_growth <- array(rnorm(1, data$prior_growth, 0.02))
       }
       out$log_R <- array(rnorm(
         n = 1, mean = convert_to_logmean(data$r_mean, data$r_sd),
-        sd = convert_to_logsd(data$r_mean, data$r_sd) * 0.1
+        sd = convert_to_logsd(data$r_mean, data$r_sd)
       ))
     }
 
@@ -640,7 +683,7 @@ create_initial_conditions <- function(data) {
       out$frac_obs <- array(truncnorm::rtruncnorm(1,
         a = 0, b = 1,
         mean = data$obs_scale_mean,
-        sd = data$obs_scale_sd * 0.1
+        sd = data$obs_scale_sd
       ))
     } else {
       out$frac_obs <- array(numeric(0))
@@ -741,33 +784,35 @@ create_stan_delays <- function(..., time_points = 1L) {
   delays <- list(...)
   ## discretise
   delays <- map(delays, discretise, strict = FALSE)
-  ## convolve where appropriate
   delays <- map(delays, collapse)
-  ## apply tolerance
-  delays <- map(delays, function(x) {
-    apply_tolerance(x, tolerance = attr(x, "tolerance"))
-  })
   ## get maximum delays
-  max_delay <- unname(as.numeric(flatten(map(delays, max))))
+  bounded_delays <- map(delays, function(x) discretise(fix_parameters(x)))
+  max_delay <- unname(as.numeric(flatten(map(bounded_delays, max))))
   ## number of different non-empty types
-  type_n <- lengths(delays)
+  type_n <- vapply(delays, ndist, integer(1))
   ## assign ID values to each type
   ids <- rep(0L, length(type_n))
   ids[type_n > 0] <- seq_len(sum(type_n > 0))
   names(ids) <- paste(names(type_n), "id", sep = "_")
 
-  flat_delays <- flatten(delays)
+  ## create "flat version" of delays, i.e. a list of all the delays (including
+  ## elements of composite delays)
+  if (length(delays) > 1) {
+    flat_delays <- do.call(c, delays)
+  } else {
+    flat_delays <- delays
+  }
   parametric <- unname(vapply(
-    flat_delays, function(x) x$distribution != "nonparametric", logical(1)
+    flat_delays, function(x) get_distribution(x) != "nonparametric", logical(1)
   ))
   param_length <- unname(vapply(flat_delays[parametric], function(x) {
-    length(x$parameters)
+    length(get_parameters(x))
   }, numeric(1)))
   nonparam_length <- unname(vapply(flat_delays[!parametric], function(x) {
     length(x$pmf)
   }, numeric(1)))
   distributions <- unname(as.character(
-    map(flat_delays[parametric], ~ .x$distribution)
+    map(flat_delays[parametric], get_distribution)
   ))
 
   ## create stan object
@@ -788,15 +833,16 @@ create_stan_delays <- function(..., time_points = 1L) {
   ret$types_groups <- array(c(0, cumsum(unname(type_n[type_n > 0]))) + 1)
 
   ret$params_mean <- array(unname(as.numeric(
-    map(flatten(map(flat_delays[parametric], ~ .x$parameters)), mean)
+    map(flatten(map(flat_delays[parametric], get_parameters)), mean)
   )))
   ret$params_sd <- array(unname(as.numeric(
-    map(flatten(map(flat_delays[parametric], ~ .x$parameters)), sd_dist)
+    map(flatten(map(flat_delays[parametric], get_parameters)), sd)
   )))
+  ret$params_sd[is.na(ret$params_sd)] <- 0
   ret$max <- array(max_delay[parametric])
 
   ret$np_pmf <- array(unname(as.numeric(
-    flatten(map(flat_delays[!parametric], ~ .x$pmf))
+    flatten(map(flat_delays[!parametric], get_pmf))
   )))
   ## get non zero length delay pmf lengths
   ret$np_pmf_groups <- array(c(0, cumsum(nonparam_length)) + 1)
@@ -809,7 +855,7 @@ create_stan_delays <- function(..., time_points = 1L) {
   ## set lower bounds
   ret$params_lower <- array(unname(as.numeric(flatten(
     map(flat_delays[parametric], function(x) {
-      lower_bounds(x$distribution)[names(x$parameters)]
+      lower_bounds(get_distribution(x))[names(get_parameters(x))]
     })
   ))))
   ## assign prior weights
