@@ -3,8 +3,16 @@
 #' @description `r lifecycle::badge("stable")`
 #' Returns generation time parameters in a format for lower level model use.
 #'
+#' @details Because the discretised renewal equation used in the package does
+#'   not support zero generation times, any distribution specified here will be
+#'   left-truncated at one, i.e. the first element of the nonparametric or
+#'   discretised probability distribution used for the generation time is set to
+#'   zero and the resulting distribution renormalised.
+#' @rdname generation_time_opts
 #' @param dist A delay distribution or series of delay distributions . If no
-#'   distribution is given a fixed generation time of 1 will be assumed.
+#'   distribution is given a fixed generation time of 1 will be assumed.  If
+#'   passing a nonparametric distribution the first element should be zero (see
+#'   *Details* section)
 #'
 #' @param ... deprecated; use `dist` instead
 #' @param disease deprecated; use `dist` instead
@@ -14,10 +22,11 @@
 #' @param weight_prior Logical; if TRUE (default), any priors given in `dist`
 #'   will be weighted by the number of observation data points, in doing so
 #'   approximately placing an independent prior at each time step and usually
-#'   preventing the posteriors from shifting. If FALSE, no weight will be
-#'   applied, i.e. any parameters in `dist` will be treated as a single
-#'    parameters.
-#' @inheritParams apply_tolerance
+#'   preventing the posteriors from shifting. If FALSE, no weight
+#'   will be applied, i.e. any parameters in `dist` will be treated as a single
+#'   parameters.
+#' @inheritParams apply_default_cdf_cutoff
+#' @importFrom cli cli_warn cli_abort col_blue
 #' @return A `<generation_time_opts>` object summarising the input delay
 #' distributions.
 #' @seealso [convert_to_logmean()] [convert_to_logsd()]
@@ -40,74 +49,55 @@
 #' )
 #'
 #' # An example generation time
-#' generation_time_opts(example_generation_time)
-generation_time_opts <- function(dist = Fixed(1), ...,
-                                 disease, source, max = 14, fixed = FALSE,
-                                 tolerance = 0.001, weight_prior = TRUE) {
-  deprecated_options_given <- FALSE
+#' gt_opts(example_generation_time)
+gt_opts <- function(dist = Fixed(1), ...,
+                    disease, source, max = 14, fixed = FALSE,
+                    default_cdf_cutoff = 0.001, weight_prior = TRUE) {
   dot_options <- list(...)
 
-  ## check consistent options are given
-  type_options <- (length(dot_options) > 0) + ## distributional parameters
-    (!missing(disease) && !missing(source)) ## from included distributions
-  if (type_options > 1) {
-    stop(
-      "Generation time can be given either as distributional options ",
-      "or as a combination of disease and source, but not both."
+  if ((length(dot_options) > 0) ||
+      !missing(disease) || !missing(source) || !missing(fixed) ||
+      !missing(max) ||
+      (!is(dist, "dist_spec"))) {
+    cli_abort(
+      c(
+        "!" = "The generation time distribution must be passed through
+      {.fn gt_opts} or {.fn generation_time_opts}. ",
+        "i" = "This behaviour has changed from previous versions of `EpiNow2`
+      and any code using it must be updated as any other ways of
+      specifying the generation time are deprecated. {col_blue(\"For
+      examples and more information, see the relevant documentation
+      pages using ?gt_opts\")}"
+      )
     )
   }
-  if (length(dot_options) > 0) {
-    if (is(dist, "dist_spec")) { ## dist not specified
-      dot_options$distribution <- "gamma"
-    }
-    ## set max
-    if (!("max" %in% names(dot_options))) {
-      dot_options$max <- max
-    }
-    ## set default of mean=1 for backwards compatibility
-    if (!("mean" %in% names(dot_options))) {
-      dot_options$mean <- 1
-    }
-    dist <- do.call(dist_spec, dot_options)
-    if (fixed) dist <- fix_dist(dist)
-    deprecated_options_given <- TRUE
-  } else if (!missing(disease) && !missing(source)) {
-    dist <- get_generation_time(disease, source, max, fixed)
-    dist$fixed <- fixed
-    deprecated_options_given <- TRUE
-  }
-  if (!is(dist, "dist_spec")) {
-    if (is.list(dist) && length(dot_options) == 0) {
-      dist <- do.call(dist_spec, dist)
-    }
-    deprecated_options_given <- TRUE
-  }
-  if (deprecated_options_given) {
-    warning(
-      "The generation time distribution should be given to ",
-      "`generation_time_opts` using a `dist_spec`. ",
-      "This behaviour has changed from previous versions of `EpiNow2` and ",
-      "any code using it may need to be updated as any other ways of ",
-      "specifying the generation time are deprecated and will be removed in ",
-      "the next version. For examples and more ",
-      "information, see the relevant documentation pages using ",
-      "`?generation_time_opts`")
-  }
   if (missing(dist)) {
-    warning(
-      "No generation time distribution given. Assuming a fixed generation ",
-      "time of 1 day, i.e. the reproduction number is the same as the daily ",
-      "growth rate. If this was intended then this warning can be silenced by ",
-      "setting `dist` explicitly to `Fixed(1)`."
+    #nolint start: duplicate_argument_linter
+    cli_warn(
+      c(
+        "!" = "No generation time distribution given.",
+        "i" = "Now using a fixed generation time of 1 day, i.e. the
+        reproduction number is the same as the daily growth rate.",
+        "i" = "If this was intended then this warning can be
+        silenced by setting {.var dist = Fixed(1)}'."
+      )
+      #nolint end
     )
   }
-  check_stan_delay(dist)
-  attr(dist, "tolerance") <- tolerance
+  ## apply default CDF cutoff if `dist` is unconstrained
+  dist <- apply_default_cdf_cutoff(
+    dist, default_cdf_cutoff, !missing(default_cdf_cutoff)
+  )
   attr(dist, "weight_prior") <- weight_prior
   attr(dist, "class") <- c("generation_time_opts", class(dist))
+  check_generation_time(dist)
   return(dist)
 }
 
+#' @rdname generation_time_opts
+#' @export
+generation_time_opts <- gt_opts
+
 #' Secondary Reports Options
 #'
 #' @description `r lifecycle::badge("stable")`
@@ -185,11 +175,11 @@ secondary_opts <- function(type = c("incidence", "prevalence"), ...) {
 #'   a fixed distribution with all mass at 0, i.e. no delay.
 #' @param ... deprecated; use `dist` instead
 #' @param fixed deprecated; use `dist` instead
-#' @inheritParams apply_tolerance
 #' @inheritParams generation_time_opts
+#' @importFrom cli cli_abort
 #' @return A `<delay_opts>` object summarising the input delay distributions.
 #' @seealso [convert_to_logmean()] [convert_to_logsd()]
-#' [bootstrapped_dist_fit()] [dist_spec()]
+#' [bootstrapped_dist_fit()] \code{\link{Distributions}}
 #' @export
 #' @examples
 #' # no delays
@@ -205,42 +195,38 @@ secondary_opts <- function(type = c("incidence", "prevalence"), ...) {
 #'
 #' # Multiple delays (in this case twice the same)
 #' delay_opts(delay + delay)
-delay_opts <- function(dist = Fixed(0), ..., fixed = FALSE, tolerance = 0.001,
-                       weight_prior = TRUE) {
+delay_opts <- function(dist = Fixed(0), ..., fixed = FALSE,
+                       default_cdf_cutoff = 0.001, weight_prior = TRUE) {
   dot_options <- list(...)
-  if (!is(dist, "dist_spec")) { ## could be old syntax
-    if (is.list(dist)) {
-      ## combine lists if more than one given
-      dot_options <- c(list(dist), dot_options)
-      dist <- lapply(dot_options, do.call, what = dist_spec)
-      if (length(dist) > 1) {
-        for (i in seq(2, length(dist))) {
-          dist[[1]] <- dist[[1]] + dist[[i]]
-        }
-      }
-      dist <- dist[[1]]
-    } else {
-      stop("`dist` should be given as result of a call to `dist_spec`.")
-    }
-    warning(
-      "Delay distributions must be of given either using a call to ",
-      "`dist_spec` or one of the `get_...` functions such as ",
-      "`get_incubation_period`. ",
-      "This behaviour has changed from previous versions of `EpiNow2` and ",
-      "any code using it may need to be updated as any other ways of ",
-      "specifying delays are deprecated and will be removed in ",
-      "the next version. For examples and more ",
-      "information, see the relevant documentation pages using ",
-      "`?delay_opts`."
+  if (!is(dist, "dist_spec") || !missing(fixed)) { ## could be old syntax
+    #nolint start: duplicate_argument_linter
+    cli_abort(
+      c(
+        "!" = "Delay distributions must be given using a call to
+        {.fn delay_opts}",
+        "i" = "This behaviour has changed from previous versions of `EpiNow2`
+      and any code using it must be updated as any other ways of specifying
+      delays are deprecated.",
+        "i" = "For examples and more information, see the relevant
+        documentation pages using {.code ?delay_opts}."
+      )
     )
+    #nolint end
   } else if (length(dot_options) > 0) {
     ## can be removed once dot options are hard deprecated
-    stop("Unknown named arguments passed to `delay_opts`")
+    cli_abort(
+      c(
+        "!" = "Unknown named arguments passed to {.fn delay_opts}."
+      )
+    )
   }
-  check_stan_delay(dist)
-  attr(dist, "tolerance") <- tolerance
+  ## apply default CDF cutoff if `dist` is unconstrained
+  dist <- apply_default_cdf_cutoff(
+    dist, default_cdf_cutoff, !missing(default_cdf_cutoff)
+  )
   attr(dist, "weight_prior") <- weight_prior
   attr(dist, "class") <- c("delay_opts", class(dist))
+  check_stan_delay(dist)
   return(dist)
 }
 
@@ -263,12 +249,13 @@ delay_opts <- function(dist = Fixed(0), ..., fixed = FALSE, tolerance = 0.001,
 #'   posteriors from shifting. If FALSE (default), no weight will be applied,
 #'   i.e. the truncation distribution will be treated as a single parameter.
 #'
-#' @inheritParams apply_tolerance
+#' @inheritParams gt_opts
+#' @importFrom cli cli_abort
 #' @return A `<trunc_opts>` object summarising the input truncation
 #' distribution.
 #'
 #' @seealso [convert_to_logmean()] [convert_to_logsd()]
-#' [bootstrapped_dist_fit()] [dist_spec()]
+#' [bootstrapped_dist_fit()] \code{\link{Distributions}}
 #' @export
 #' @examples
 #' # no truncation
@@ -276,27 +263,30 @@ delay_opts <- function(dist = Fixed(0), ..., fixed = FALSE, tolerance = 0.001,
 #'
 #' # truncation dist
 #' trunc_opts(dist = LogNormal(mean = 3, sd = 2, max = 10))
-trunc_opts <- function(dist = Fixed(0), tolerance = 0.001,
+trunc_opts <- function(dist = Fixed(0), default_cdf_cutoff = 0.001,
                        weight_prior = FALSE) {
   if (!is(dist, "dist_spec")) {
-    if (is.list(dist)) {
-      dist <- do.call(dist_spec, dist)
-    }
-    warning(
-      "Truncation distributions must be of given either using a call to ",
-      "`dist_spec` or one of the `get_...` functions. ",
-      "This behaviour has changed from previous versions of `EpiNow2` and ",
-      "any code using it may need to be updated as any other ways of ",
-      "specifying delays are deprecated and will be removed in ",
-      "the next version. For examples and more ",
-      "information, see the relevant documentation pages using ",
-      "`?trunc_opts`"
+    #nolint start: duplicate_argument_linter
+    cli_abort(
+      c(
+        "!" = "Truncation distributions must be given using a call to
+        {.fn trunc_opts}.",
+        "i" = "This behaviour has changed from previous versions of `EpiNow2`
+      and any code using it must be updated as any other ways of specifying
+      delays are deprecated.",
+        "i" = "For examples and more information, see the relevant
+        documentation pages using {.code ?trunc_opts}."
+      )
+    #nolint end
     )
   }
-  check_stan_delay(dist)
-  attr(dist, "tolerance") <- tolerance
+  ## apply default CDF cutoff if `dist` is unconstrained
+  dist <- apply_default_cdf_cutoff(
+    dist, default_cdf_cutoff, !missing(default_cdf_cutoff)
+  )
   attr(dist, "weight_prior") <- weight_prior
   attr(dist, "class") <- c("trunc_opts", class(dist))
+  check_stan_delay(dist)
   return(dist)
 }
 
@@ -342,6 +332,7 @@ trunc_opts <- function(dist = Fixed(0), tolerance = 0.001,
 #' reproduction number.
 #' @inheritParams create_future_rt
 #' @importFrom rlang arg_match
+#' @importFrom cli cli_abort
 #' @export
 #' @examples
 #' # default settings
@@ -375,7 +366,13 @@ rt_opts <- function(prior = list(mean = 1, sd = 1),
   }
 
   if (!("mean" %in% names(rt$prior) && "sd" %in% names(rt$prior))) {
-    stop("prior must have both a mean and sd specified")
+    cli_abort(
+      c(
+        "!" = "{.var prior} must have both {.var mean} and {.var sd}
+        specified.",
+        "i" = "Did you forget to specify {.var mean} and/or {.var sd}?"
+      )
+    )
   }
   attr(rt, "class") <- c("rt_opts", class(rt))
   return(rt)
@@ -409,6 +406,7 @@ rt_opts <- function(prior = list(mean = 1, sd = 1),
 #' average to use when estimating Rt. This must be odd so that the central
 #' estimate is included.
 #' @importFrom rlang arg_match
+#' @importFrom cli cli_abort
 #'
 #' @return A `<backcalc_opts>` object of back calculation settings.
 #' @export
@@ -423,9 +421,12 @@ backcalc_opts <- function(prior = c("reports", "none", "infections"),
     rt_window = as.integer(rt_window)
   )
   if (backcalc$rt_window %% 2 == 0) {
-    stop(
-      "Rt rolling average window must be odd in order to include the current
-       estimate"
+    cli_abort(
+      c(
+        "!" = "{.var rt_window} must be odd in order to
+        include the current estimate.",
+        "i" = "You have supplied an even number."
+      )
     )
   }
   attr(backcalc, "class") <- c("backcalc_opts", class(backcalc))
@@ -436,7 +437,7 @@ backcalc_opts <- function(prior = c("reports", "none", "infections"),
 #'
 #' @description `r lifecycle::badge("stable")`
 #' Defines a list specifying the structure of the approximate Gaussian
-#'  process. Custom settings can be supplied which override the defaults.
+#' process. Custom settings can be supplied which override the defaults.
 #'
 #' @param ls_mean Numeric, defaults to 21 days. The mean of the lognormal
 #' length scale.
@@ -446,25 +447,34 @@ backcalc_opts <- function(prior = c("reports", "none", "infections"),
 #' process length scale will be used with recommended parameters
 #' \code{inv_gamma(1.499007, 0.057277 * ls_max)}.
 #'
+#' @param ls_min Numeric, defaults to 0. The minimum value of the length scale.
+#'
 #' @param ls_max Numeric, defaults to 60. The maximum value of the length
 #' scale. Updated in [create_gp_data()] to be the length of the input data if
 #' this is smaller.
 #'
-#' @param ls_min Numeric, defaults to 0. The minimum value of the length scale.
+#' @param alpha_mean Numeric, defaults to 0. The mean of the magnitude parameter
+#' of the Gaussian process kernel. Should be approximately the expected variance
+#' of the logged Rt.
 #'
-#' @param alpha_sd Numeric, defaults to 0.05. The standard deviation of the
-#'  magnitude parameter of the Gaussian process kernel. Should be approximately
+#' @param alpha_sd Numeric, defaults to 0.01. The standard deviation of the
+#' magnitude parameter of the Gaussian process kernel. Should be approximately
 #' the expected standard deviation of the logged Rt.
 #'
 #' @param kernel Character string, the type of kernel required. Currently
-#' supporting the squared exponential kernel ("se") and the 3 over 2 Matern
-#' kernel ("matern", with `matern_type = 3/2`). Defaulting to the Matern 3 over
-#' 2 kernel as discontinuities are expected  in Rt and infections.
+#' supporting the Matern kernel ("matern"), squared exponential kernel ("se"),
+#' periodic kernel, Ornstein-Uhlenbeck #' kernel ("ou"), and the periodic
+#' kernel ("periodic").
 #'
-#' @param matern_type Numeric, defaults to 3/2. Type of Matern Kernel to use.
-#' Currently only the Matern 3/2 kernel is supported.
+#' @param matern_order Numeric, defaults to 3/2. Order of Matérn Kernel to use.
+#' Common choices are 1/2, 3/2, and 5/2. If `kernel` is set
+#' to "ou", `matern_order` will be automatically set to 1/2. Only used if
+#' the kernel is set to "matern".
 #'
-#' @param basis_prop Numeric, proportion of time points to use as basis
+#' @param matern_type Deprecated; Numeric, defaults to 3/2. Order of Matérn
+#' Kernel to use. Currently, the orders 1/2, 3/2, 5/2 and Inf are supported.
+#'
+#' @param basis_prop Numeric, the proportion of time points to use as basis
 #' functions. Defaults to 0.2. Decreasing this value results in a decrease in
 #' accuracy but a faster compute time (with increasing it having the first
 #' effect). In general smaller posterior length scales require a higher
@@ -475,7 +485,11 @@ backcalc_opts <- function(prior = c("reports", "none", "infections"),
 #' approximate Gaussian process. See (Riutort-Mayol et al. 2020
 #' <https://arxiv.org/abs/2004.11408>) for advice on updating this default.
 #'
+#' @param w0 Numeric, defaults to 1.0. Fundamental frequency for periodic
+#' kernel. They are only used if `kernel` is set to "periodic".
+#'
 #' @importFrom rlang arg_match
+#' @importFrom cli cli_abort cli_warn
 #' @return A `<gp_opts>` object of settings defining the Gaussian process
 #' @export
 #' @examples
@@ -484,15 +498,57 @@ backcalc_opts <- function(prior = c("reports", "none", "infections"),
 #'
 #' # add a custom length scale
 #' gp_opts(ls_mean = 4)
+#'
+#' # use linear kernel
+#' gp_opts(kernel = "periodic")
 gp_opts <- function(basis_prop = 0.2,
                     boundary_scale = 1.5,
                     ls_mean = 21,
                     ls_sd = 7,
                     ls_min = 0,
                     ls_max = 60,
-                    alpha_sd = 0.05,
-                    kernel = c("matern_3/2", "se"),
-                    matern_type = 3 / 2) {
+                    alpha_mean = 0,
+                    alpha_sd = 0.01,
+                    kernel = c("matern", "se", "ou", "periodic"),
+                    matern_order = 3 / 2,
+                    matern_type,
+                    w0 = 1.0) {
+
+  if (!missing(matern_type)) {
+    lifecycle::deprecate_warn(
+      "1.6.0", "gp_opts(matern_type)", "gp_opts(matern_order)"
+    )
+  }
+
+  if (!missing(matern_type)) {
+    if (!missing(matern_order) && matern_type != matern_order) {
+      cli_abort(
+        c(
+          "!" = "{.var matern_order} and {.var matern_type} must be the same, if
+          both are supplied.",
+          "i" = "Rather only use {.var matern_order} only."
+        )
+      )
+    }
+    matern_order <- matern_type
+  }
+
+  kernel <- arg_match(kernel)
+  if (kernel == "se") {
+    matern_order <- Inf
+  } else if (kernel == "ou") {
+    matern_order <- 1 / 2
+  } else if (
+      !(is.infinite(matern_order) || matern_order %in% c(1 / 2, 3 / 2, 5 / 2))
+    ) {
+    cli_warn(
+      c(
+        "!" = "Uncommon Matern kernel order supplied.",
+        "i" = "Use one of `1 / 2`, `3 / 2`, or `5 / 2`" # nolint
+      )
+    )
+  }
+
   gp <- list(
     basis_prop = basis_prop,
     boundary_scale = boundary_scale,
@@ -500,14 +556,13 @@ gp_opts <- function(basis_prop = 0.2,
     ls_sd = ls_sd,
     ls_min = ls_min,
     ls_max = ls_max,
+    alpha_mean = alpha_mean,
     alpha_sd = alpha_sd,
-    kernel = arg_match(kernel),
-    matern_type = matern_type
+    kernel = kernel,
+    matern_order = matern_order,
+    w0 = w0
   )
 
-  if (gp$matern_type != 3 / 2) {
-    stop("only the Matern 3/2 kernel is currently supported") # nolint
-  }
   attr(gp, "class") <- c("gp_opts", class(gp))
   return(gp)
 }
@@ -522,8 +577,10 @@ gp_opts <- function(basis_prop = 0.2,
 #' @param phi Overdispersion parameter of the reporting process, used only if
 #'   `familiy` is "negbin". Can be supplied either as a single numeric value
 #'   (fixed overdispersion) or a list with numeric elements mean (`mean`) and
-#'   standard deviation (`sd`) defining a normally distributed overdispersion.
-#'   Defaults to a list with elements `mean = 0` and `sd = 1`.
+#'   standard deviation (`sd`) defining a normally distributed prior.
+#'   Internally parameterised such that the overdispersion is one over the
+#'   square of this prior overdispersion. Defaults to a list with elements
+#'   `mean = 0` and `sd = 0.25`.
 #' @param weight Numeric, defaults to 1. Weight to give the observed data in the
 #'   log density.
 #' @param week_effect Logical defaulting to `TRUE`. Should a day of the week
@@ -550,6 +607,7 @@ gp_opts <- function(basis_prop = 0.2,
 #' @param return_likelihood Logical, defaults to `FALSE`. Should the likelihood
 #'   be returned by the model.
 #' @importFrom rlang arg_match
+#' @importFrom cli cli_inform cli_abort
 #' @return An `<obs_opts>` object of observation model settings.
 #' @export
 #' @examples
@@ -562,7 +620,7 @@ gp_opts <- function(basis_prop = 0.2,
 #' # Scale reported data
 #' obs_opts(scale = list(mean = 0.2, sd = 0.02))
 obs_opts <- function(family = c("negbin", "poisson"),
-                     phi = list(mean = 0, sd = 1),
+                     phi = list(mean = 0, sd = 0.25),
                      weight = 1,
                      week_effect = TRUE,
                      week_length = 7,
@@ -572,22 +630,30 @@ obs_opts <- function(family = c("negbin", "poisson"),
                      return_likelihood = FALSE) {
   na <- arg_match(na)
   if (na == "accumulate") {
-    message(
-      "Accumulating modelled values that correspond to NA values in the data ",
-      "by adding them to the next non-NA data point. This means that the ",
-      "first data point is not included in the likelihood but used only to ",
-      "reset modelled observations to zero. If the first data point should be ",
-      "included in the likelihood this can be achieved by adding a data point ",
-      "of arbitrary value before the first data point."
+    #nolint start: duplicate_argument_linter
+    cli_inform(
+      c(
+        "i" = "Accumulating modelled values that correspond to NA values in the
+      data by adding them to the next non-NA data point.",
+        "i" = "This means that the first data point is not included in the
+      likelihood but used only to reset modelled observations to zero.",
+        "i" = "{col_red('If the first data point should be included in the
+        likelihood this can be achieved by adding a data point of arbitrary
+        value before the first data point.')}"
+      ),
+      .frequency = "regularly",
+      .frequency_id = "obs_opts"
     )
+  #nolint end
   }
 
   if (length(phi) == 2 && is.numeric(phi)) {
-    warning(
-      "Specifying `phi` as a length 2 vector is deprecated. Mean and SD ",
-      "should be given as list elements."
+    cli_abort(
+      c(
+        "!" = "Specifying {.var phi} as a vector of length 2 is deprecated.",
+        "i" = "Mean and SD should be given as list elements."
+      )
     )
-    phi <- list(mean = phi[1], sd = phi[2])
   }
   obs <- list(
     family = arg_match(family),
@@ -606,7 +672,13 @@ obs_opts <- function(family = c("negbin", "poisson"),
       obs[[param]] <- list(mean = obs[[param]], sd = 0)
     }
     if (!(all(c("mean", "sd") %in% names(obs[[param]])))) {
-      stop("If specifying a ", param, " as list both a mean and sd are needed")
+      cli_abort(
+        c(
+          "!" = "Both a {.var mean} and {.var sd} are needed if specifying
+        {.strong {param}} as list.",
+          "i" = "Did you forget to specify {.var mean} and/or {.var sd}?"
+        )
+      )
     }
   }
 
@@ -614,33 +686,6 @@ obs_opts <- function(family = c("negbin", "poisson"),
   return(obs)
 }
 
-#' Rstan Sampling Options
-#'
-#' @description `r lifecycle::badge("deprecated")`
-#' Deprecated; use [stan_sampling_opts()] instead.
-#' @inheritParams stan_sampling_opts
-#' @return A list of arguments to pass to [rstan::sampling()].
-#' @export
-rstan_sampling_opts <- function(cores = getOption("mc.cores", 1L),
-                                warmup = 250,
-                                samples = 2000,
-                                chains = 4,
-                                control = list(),
-                                save_warmup = FALSE,
-                                seed = as.integer(runif(1, 1, 1e8)),
-                                future = FALSE,
-                                max_execution_time = Inf,
-                                ...) {
-  lifecycle::deprecate_warn(
-    "1.5.0", "rstan_sampling_opts()",
-    "stan_sampling_opts()"
-  )
-  return(stan_sampling_opts(
-    cores, warmup, samples, chains, control, save_warmup, seed, future,
-    max_execution_time, backend = "rstan", ...
-  ))
-}
-
 #' Stan Sampling Options
 #'
 #' @description `r lifecycle::badge("stable")`
@@ -661,8 +706,8 @@ rstan_sampling_opts <- function(cores = getOption("mc.cores", 1L),
 #' @param chains Numeric, defaults to 4. Number of MCMC chains to use.
 #'
 #' @param control List, defaults to empty. control parameters to pass to
-#' underlying `rstan` function. By default `adapt_delta = 0.95` and
-#' `max_treedepth = 15` though these settings can be overwritten.
+#' underlying `rstan` function. By default `adapt_delta = 0.9` and
+#' `max_treedepth = 12` though these settings can be overwritten.
 #'
 #' @param save_warmup Logical, defaults to FALSE. Should warmup progress be
 #' saved.
@@ -683,10 +728,12 @@ rstan_sampling_opts <- function(cores = getOption("mc.cores", 1L),
 #'
 #' @inheritParams stan_opts
 #'
-#' @param ... Additional parameters to pass to [rstan::sampling()].
+#' @param ... Additional parameters to pass to [rstan::sampling()] or
+#' [cmdstanr::sample()].
 #' @importFrom utils modifyList
+#' @importFrom cli cli_warn
 #' @return A list of arguments to pass to [rstan::sampling()] or
-#' [cmdstanr::sample().
+#' [cmdstanr::sample()].
 #' @export
 #' @examples
 #' stan_sampling_opts(samples = 2000)
@@ -710,12 +757,14 @@ stan_sampling_opts <- function(cores = getOption("mc.cores", 1L),
     future = future,
     max_execution_time = max_execution_time
   )
-  control_def <- list(adapt_delta = 0.95, max_treedepth = 15)
+  control_def <- list(adapt_delta = 0.9, max_treedepth = 12)
   control_def <- modifyList(control_def, control)
   if (any(c("iter", "iter_sampling") %in% names(dot_args))) {
-    warning(
-      "Number of samples should be specified using the `samples` and `warmup`",
-      "arguments rather than `iter` or `iter_sampliing` which will be ignored."
+    cli_warn(
+      "!" = "Number of samples must be specified using the {.var samples}
+      and {.var warmup} arguments rather than {.var iter} or
+      {.var iter_sampliing}.",
+      "i" = "Supplied {.var iter} or {.var iter_sampliing} will be ignored."
     )
   }
   dot_args$iter <- NULL
@@ -738,23 +787,6 @@ stan_sampling_opts <- function(cores = getOption("mc.cores", 1L),
   return(opts)
 }
 
-#' Rstan Variational Bayes Options
-#'
-#' @description `r lifecycle::badge("deprecated")`
-#' Deprecated; use [stan_vb_opts()] instead.
-#' @inheritParams stan_vb_opts
-#' @return A list of arguments to pass to [rstan::vb()].
-#' @export
-rstan_vb_opts <- function(samples = 2000,
-                          trials = 10,
-                          iter = 10000, ...) {
-  lifecycle::deprecate_warn(
-    "1.5.0", "rstan_vb_opts()",
-    "stan_vb_opts()"
-  )
-  return(stan_vb_opts(samples, trials, iter, ...))
-}
-
 #' Stan Variational Bayes Options
 #'
 #' @description `r lifecycle::badge("stable")`
@@ -799,6 +831,7 @@ stan_vb_opts <- function(samples = 2000,
 #' @inheritParams stan_opts
 #' @inheritParams stan_vb_opts
 #' @param ... Additional parameters to pass to [cmdstanr::laplace()].
+#' @importFrom cli cli_abort col_blue
 #' @return A list of arguments to pass to [cmdstanr::laplace()].
 #' @export
 #' @examples
@@ -807,8 +840,12 @@ stan_laplace_opts <- function(backend = "cmdstanr",
                               trials = 10,
                               ...) {
   if (backend != "cmdstanr") {
-    stop(
-      "The Laplace algorithm is only available with the \"cmdstanr\" backend."
+    cli_abort(
+      c(
+        "!" = "Backend must be set to {col_blue(\"cmdstanr\")} to use
+        the Laplace algorithm.",
+        "i" = "Change {.var backend} to col_blue(\"cmdstanr\")}."
+      )
     )
   }
   opts <- list(trials = trials)
@@ -824,6 +861,7 @@ stan_laplace_opts <- function(backend = "cmdstanr",
 #' @inheritParams stan_opts
 #' @inheritParams stan_vb_opts
 #' @param ... Additional parameters to pass to [cmdstanr::laplace()].
+#' @importFrom cli cli_abort col_blue
 #' @return A list of arguments to pass to [cmdstanr::laplace()].
 #' @export
 #' @examples
@@ -833,9 +871,12 @@ stan_pathfinder_opts <- function(backend = "cmdstanr",
                                  trials = 10,
                                  ...) {
   if (backend != "cmdstanr") {
-    stop(
-      "The pathfinder algorithm is only available with the \"cmdstanr\" ",
-      "backend."
+    cli_abort(
+      c(
+        "!" = "Backend must be set to {col_blue(\"cmdstanr\")} to use
+        the pathfinder algorithm.",
+        "i" = "Change {.var backend} to col_blue(\"cmdstanr\")}."
+      )
     )
   }
   opts <- list(
@@ -846,51 +887,6 @@ stan_pathfinder_opts <- function(backend = "cmdstanr",
   return(opts)
 }
 
-#' Rstan Options
-#'
-#' @description `r lifecycle::badge("deprecated")`
-#' Deprecated; specify options in [stan_opts()] instead.
-#'
-#' @param object Stan model object. By default uses the compiled package
-#' default.
-#'
-#' @param method A character string, defaulting to sampling. Currently supports
-#' [rstan::sampling()] ("sampling") or [rstan::vb()].
-#'
-#' @param ... Additional parameters to pass  underlying option functions.
-#' @importFrom rlang arg_match
-#' @return A list of arguments to pass to the appropriate rstan functions.
-#' @export
-#' @inheritParams rstan_sampling_opts
-#' @seealso [rstan_sampling_opts()] [rstan_vb_opts()]
-rstan_opts <- function(object = NULL,
-                       samples = 2000,
-                       method = c("sampling", "vb"), ...) {
-  lifecycle::deprecate_warn(
-    "1.5.0", "rstan_opts()",
-    "stan_opts()"
-  )
-  method <- arg_match(method)
-  # shared everywhere opts
-  if (is.null(object)) {
-    object <- stanmodels$estimate_infections
-  }
-  opts <- list(
-    object = object,
-    method = method
-  )
-  if (method == "sampling") {
-    opts <- c(
-      opts, stan_sampling_opts(samples = samples, backend = "rstan", ...)
-    )
-  } else if (method == "vb") {
-    opts <- c(
-      opts, stan_vb_opts(samples = samples, ...)
-    )
-  }
-  return(opts)
-}
-
 #' Stan Options
 #'
 #' @description `r lifecycle::badge("stable")`
@@ -911,21 +907,8 @@ rstan_opts <- function(object = NULL,
 #' @param backend Character string indicating the backend to use for fitting
 #' stan models. Supported arguments are "rstan" (default) or "cmdstanr".
 #'
-#' @param init_fit `r lifecycle::badge("experimental")`
-#' Character string or `stanfit` object, defaults to NULL. Should an initial
-#' fit be used to initialise the full fit. An example scenario would be using a
-#' national level fit to parametrise regional level fits. Optionally a
-#' character string can be passed with the currently supported option being
-#' "cumulative". This fits the model to cumulative cases and may be useful for
-#' certain data sets where the sampler gets stuck or struggles to initialise.
-#' See [init_cumulative_fit()] for details.
-#'
-#' This implementation is based on the approach taken in
-#' [epidemia](https://github.com/ImperialCollegeLondon/epidemia/) authored by
-#' James Scott.
-#'
-#' This argument is deprecated and the default (NULL) will be used from
-#' the next version.
+#' @param init_fit `r lifecycle::badge("deprecated")`
+#' This argument is deprecated.
 #'
 #' @param return_fit Logical, defaults to TRUE. Should the fit stan model be
 #' returned.
@@ -934,6 +917,7 @@ rstan_opts <- function(object = NULL,
 #'   [stan_sampling_opts()] or [stan_vb_opts()], depending on the method
 #'
 #' @importFrom rlang arg_match
+#' @importFrom cli cli_abort cli_warn col_blue
 #' @return A `<stan_opts>` object of arguments to pass to the appropriate
 #' rstan functions.
 #' @export
@@ -956,17 +940,22 @@ stan_opts <- function(object = NULL,
   backend_passed <- !missing(backend)
   backend <- arg_match(backend)
   if (backend == "cmdstanr" && !requireNamespace("cmdstanr", quietly = TRUE)) {
-    stop(
-      "The `cmdstanr` package needs to be installed for using the ",
-      "\"cmdstanr\" backend."
+    cli_abort(
+      c(
+        "x" = "The {col_blue('cmdstanr')} R package is not installed.",
+        "i" = "Install it from {.url https://github.com/stan-dev/cmdstanr}
+        to use the {col_blue('cmdstanr')} backend."
+      )
     )
   }
   opts <- list()
   if (!is.null(object)) {
     if (backend_passed) {
-      warning(
-        "`backend` option will be ignored as a stan model object has been ",
-        "passed."
+      cli_warn(
+        c(
+          "!" = "{.var backend} option will be ignored as a stan model
+        object has been passed."
+        )
       )
     }
     if (inherits(object, "stanmodel")) {
@@ -974,7 +963,11 @@ stan_opts <- function(object = NULL,
     } else if (inherits(object, "CmdStanModel")) {
       backend <- "cmdstanr"
     } else {
-      stop("`object` must be a stan model object")
+      cli_abort(
+        c(
+          "!" = "{.var object} must be a stan model object."
+        )
+      )
     }
   } else {
     backend <- arg_match(backend, values = c("rstan", "cmdstanr"))
@@ -1001,16 +994,10 @@ stan_opts <- function(object = NULL,
   }
 
   if (!is.null(init_fit)) {
-    deprecate_warn(
+    deprecate_stop(
       when = "1.5.0",
-      what = "stan_opts(init_fit)",
-      details = paste("This argument is deprecated and the default (NULL)",
-                      "will be used from the next version.")
+      what = "stan_opts(init_fit)"
     )
-    if (is.character(init_fit)) {
-      init_fit <- arg_match(init_fit, values = "cumulative")
-    }
-    opts$init_fit <- init_fit
   }
   opts <- c(opts, list(return_fit = return_fit))
   attr(opts, "class") <- c("stan_opts", class(opts))
@@ -1086,3 +1073,40 @@ filter_opts <- function(opts, region) {
   }
   return(out)
 }
+
+#' Apply default CDF cutoff to a <dist_spec> if it is unconstrained
+#'
+#' @param dist A <dist_spec>
+#' @param default_cdf_cutoff Numeric; default CDF cutoff to be used if an
+#'   unconstrained distribution is passed as `dist`. If `dist` is already
+#'   constrained by having a maximum or CDF cutoff this is ignored.
+#' @param cdf_cutoff_set Logical; whether the default CDF cutoff has been set by
+#'   the user; if yes and `dist` is constrained a warning is issued
+#' @importFrom cli cli_inform cli_warn
+#'
+#' @return A <dist_spec> with the default CDF cutoff set if previously not
+#'   constrained
+#' @keywords internal
+apply_default_cdf_cutoff <- function(dist, default_cdf_cutoff, cdf_cutoff_set) {
+  if (!is_constrained(dist) && !is.na(sd(dist))) {
+    #nolint start: duplicate_argument_linter
+    cli_inform(
+      c(
+        "i" = "Unconstrained distributon passed as a delay. ",
+        "i" = "Constraining with default CDF cutoff {default_cdf_cutoff}.",
+        "i" = "To silence this message, specify delay distributions
+      with {.var max} or {.var tolerance}."
+      )
+    )
+    #nolint end
+    attr(dist, "cdf_cutoff") <- default_cdf_cutoff
+  } else if (cdf_cutoff_set) {
+    cli_warn(
+      c(
+        "!" = "Ignoring given default CDF cutoff.",
+        "i" = "Distribution is already constrained."
+      )
+    )
+  }
+  return(dist)
+}
